# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.key_value_api import KeyValueApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestKeyValueApi(unittest.TestCase):
    """KeyValueApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.key_value_api.KeyValueApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_store(self):
        """Test case for create_store

        Create a new key-value store.  # noqa: E501
        """
        pass

    def test_delete_key(self):
        """Test case for delete_key

        Remove an entry from the key-value store.  # noqa: E501
        """
        pass

    def test_delete_store(self):
        """Test case for delete_store

        Deletes an existing key-value store.  # noqa: E501
        """
        pass

    def test_get_key(self):
        """Test case for get_key

        Get a Key-Value entry  # noqa: E501
        """
        pass

    def test_get_store(self):
        """Test case for get_store

        Get information about a Key-Value store  # noqa: E501
        """
        pass

    def test_list_keys(self):
        """Test case for list_keys

        Get the list of keys currently in a store.  # noqa: E501
        """
        pass

    def test_list_stores(self):
        """Test case for list_stores

        Get information about all Key-Value stores  # noqa: E501
        """
        pass

    def test_put_key(self):
        """Test case for put_key

        Place an entry into the key-value store.  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import seaplane.gen.carrier
from seaplane.gen.carrier.models.switch_cases_inner_output import (
    SwitchCasesInnerOutput,
)  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestSwitchCasesInnerOutput(unittest.TestCase):
    """SwitchCasesInnerOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SwitchCasesInnerOutput
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `SwitchCasesInnerOutput`
        """
        model = seaplane.gen.carrier.models.switch_cases_inner_output.SwitchCasesInnerOutput()  # noqa: E501
        if include_optional :
            return SwitchCasesInnerOutput(
                carrier = seaplane.gen.carrier.models.carrier_output.CarrierOutput(
                    subject = 'foo', 
                    max_in_flight = 1, ), 
                sync_response = seaplane.gen.carrier.models.sync_response.SyncResponse(
                    status = '200', 
                    headers = {"Content-Type":"application/octet-stream"}, 
                    metadata_headers = seaplane.gen.carrier.models.metadata_headers.MetadataHeaders(
                        include_prefixes = [
                            'foo_'
                            ], 
                        include_patterns = [
                            '.*'
                            ], ), ), 
                drop = seaplane.gen.carrier.models.drop.Drop(), 
                http_client = seaplane.gen.carrier.models.http_client_output.HttpClientOutput(
                    url = 'www.example.com', 
                    method = 'POST', 
                    headers = {"X-HEADER-1":"Value 1","X-HEADER-2":"Value 2"}, ), 
                azure_blob_storage = seaplane.gen.carrier.models.azure_blob_storage_output.AzureBlobStorageOutput(
                    storage_account = '', 
                    storage_access_key = '', 
                    storage_sas_token = '', 
                    storage_connection_string = '', 
                    container = 'foo', 
                    path = '${!count("files")}-${!timestamp_unix_nano()}.txt', 
                    blob_type = 'BLOCK', 
                    public_access_level = 'PRIVATE', 
                    max_in_flight = 64, ), 
                sql_raw = seaplane.gen.carrier.models.sql_raw.SqlRaw(
                    driver = 'postgres', 
                    dsn = 'postgres://foouser:foopass@localhost:5432/foodb?sslmode=disable', 
                    query = 'INSERT INTO footable (foo, bar, baz) VALUES (?, ?, ?);', 
                    args_mapping = 'root = [ this.cat.meow, this.doc.woofs[0] ]', 
                    init_statement = 'CREATE TABLE IF NOT EXISTS some_table (
  foo varchar(50) not null,
  bar integer,
  baz varchar(50),
  primary key (foo)
) WITHOUT ROWID;
', )
            )
        else :
            return SwitchCasesInnerOutput(
        )
        """

    def testSwitchCasesInnerOutput(self):
        """Test SwitchCasesInnerOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from pydantic import BaseModel, Field, constr, validator
from seaplane.gen.carrier.models.switch_cases_inner_output import SwitchCasesInnerOutput


class SwitchCasesInner(BaseModel):
    """
    A switch case
    """

    check: constr(strict=True) = Field(..., description="Bloblang boolean expression")
    output: SwitchCasesInnerOutput = Field(...)
    __properties = ["check", "output"]

    @validator("check")
    def check_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^.+$", value):
            raise ValueError(r"must validate the regular expression /^.+$/")
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SwitchCasesInner:
        """Create an instance of SwitchCasesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of output
        if self.output:
            _dict["output"] = self.output.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SwitchCasesInner:
        """Create an instance of SwitchCasesInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SwitchCasesInner.parse_obj(obj)

        _obj = SwitchCasesInner.parse_obj(
            {
                "check": obj.get("check"),
                "output": SwitchCasesInnerOutput.from_dict(obj.get("output"))
                if obj.get("output") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import seaplane.gen.carrier
from seaplane.gen.carrier.models.carrier_stream import CarrierStream  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestCarrierStream(unittest.TestCase):
    """CarrierStream unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CarrierStream
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CarrierStream`
        """
        model = seaplane.gen.carrier.models.carrier_stream.CarrierStream()  # noqa: E501
        if include_optional :
            return CarrierStream(
                name = 'example-stream', 
                options = seaplane.gen.carrier.models.carrier_stream_options.CarrierStreamOptions(
                    message_ttl = 3600, 
                    max_messages = 1000000, 
                    max_size = 100000000, 
                    replicas = 3, 
                    allow_locations = ["region/xn"], 
                    deny_locations = ["country/nl"], 
                    wait_for_ack = True, 
                    ack_timeout = 5, 
                    max_delivery_attempts = 5, 
                    max_delivery_time = 60, 
                    dead_letter_sink = 'dead-letter-sink', 
                    allow_direct = False, ), 
                details = seaplane.gen.carrier.models.carrier_stream_details.CarrierStreamDetails(
                    creation_ts = 1677252000, 
                    stored_messages = 1000, 
                    stored_messages_size = 1000000000, 
                    first_message_seq = 1001, 
                    first_message_ts = 1677252001, 
                    last_message_seq = 2000, 
                    last_message_ts = 1677252999, 
                    subjects = {"subject_foo":10,"subject_bar":20}, )
            )
        else :
            return CarrierStream(
        )
        """

    def testCarrierStream(self):
        """Test CarrierStream"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import seaplane.gen.carrier
from seaplane.gen.carrier.models.input import Input  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestInput(unittest.TestCase):
    """Input unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Input
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Input`
        """
        model = seaplane.gen.carrier.models.input.Input()  # noqa: E501
        if include_optional :
            return Input(
                carrier = seaplane.gen.carrier.models.carrier_input_config.CarrierInputConfig(
                    stream = 'example-stream', 
                    subject = 'example-stream.subject1 example-stream.subject2', 
                    queue = 'example-queue-group', 
                    durable = 'example-consumer', 
                    bind = False, 
                    deliver = 'all', 
                    ack_wait = '30s', 
                    max_ack_pending = 1024, ), 
                http_server = seaplane.gen.carrier.models.http_server_config.HTTPServerConfig(
                    address = '', 
                    path = '/', 
                    ws_path = '/post/ws', 
                    ws_welcome_message = '', 
                    ws_rate_limit_message = '', 
                    allowed_verbs = ["POST"], 
                    timeout = '5s', 
                    rate_limit = '', 
                    cert_file = '', 
                    key_file = '', 
                    cors = seaplane.gen.carrier.models.cors.Cors(
                        enabled = False, 
                        allowed_origins = [
                            'example.com'
                            ], ), ), 
                broker = [
                    seaplane.gen.carrier.models.broker_item.BrokerItem(
                        carrier = seaplane.gen.carrier.models.carrier_input_config.CarrierInputConfig(
                            stream = 'example-stream', 
                            subject = 'example-stream.subject1 example-stream.subject2', 
                            queue = 'example-queue-group', 
                            durable = 'example-consumer', 
                            bind = False, 
                            deliver = 'all', 
                            ack_wait = '30s', 
                            max_ack_pending = 1024, ), 
                        http_server = seaplane.gen.carrier.models.http_server_config.HTTPServerConfig(
                            address = '', 
                            path = '/', 
                            ws_path = '/post/ws', 
                            ws_welcome_message = '', 
                            ws_rate_limit_message = '', 
                            allowed_verbs = ["POST"], 
                            timeout = '5s', 
                            rate_limit = '', 
                            cert_file = '', 
                            key_file = '', 
                            cors = seaplane.gen.carrier.models.cors.Cors(
                                enabled = False, 
                                allowed_origins = [
                                    'example.com'
                                    ], ), ), )
                    ]
            )
        else :
            return Input(
        )
        """

    def testInput(self):
        """Test Input"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


# import models into model package
from seaplane.gen.carrier.models.azure_blob_storage_output import AzureBlobStorageOutput
from seaplane.gen.carrier.models.broker_item import BrokerItem
from seaplane.gen.carrier.models.bucket import Bucket
from seaplane.gen.carrier.models.carrier_input_config import CarrierInputConfig
from seaplane.gen.carrier.models.carrier_output import CarrierOutput
from seaplane.gen.carrier.models.carrier_stream import CarrierStream
from seaplane.gen.carrier.models.carrier_stream_details import CarrierStreamDetails
from seaplane.gen.carrier.models.carrier_stream_options import CarrierStreamOptions
from seaplane.gen.carrier.models.cors import Cors
from seaplane.gen.carrier.models.docker_processor import DockerProcessor
from seaplane.gen.carrier.models.docker_processor_docker import DockerProcessorDocker
from seaplane.gen.carrier.models.docker_processor_resources import (
    DockerProcessorResources,
)
from seaplane.gen.carrier.models.docker_processor_resources_limits import (
    DockerProcessorResourcesLimits,
)
from seaplane.gen.carrier.models.docker_processor_resources_requests import (
    DockerProcessorResourcesRequests,
)
from seaplane.gen.carrier.models.error import Error
from seaplane.gen.carrier.models.flow import Flow
from seaplane.gen.carrier.models.get_store200_response import GetStore200Response
from seaplane.gen.carrier.models.http_server_config import HTTPServerConfig
from seaplane.gen.carrier.models.http_client_output import HttpClientOutput
from seaplane.gen.carrier.models.input import Input
from seaplane.gen.carrier.models.key_value_config import KeyValueConfig
from seaplane.gen.carrier.models.metadata_headers import MetadataHeaders
from seaplane.gen.carrier.models.object_stat import ObjectStat
from seaplane.gen.carrier.models.output import Output
from seaplane.gen.carrier.models.processor import Processor
from seaplane.gen.carrier.models.secret import Secret
from seaplane.gen.carrier.models.sql_raw import SqlRaw
from seaplane.gen.carrier.models.submit_to_endpoint201_response import (
    SubmitToEndpoint201Response,
)
from seaplane.gen.carrier.models.switch import Switch
from seaplane.gen.carrier.models.switch_cases_inner import SwitchCasesInner
from seaplane.gen.carrier.models.switch_cases_inner_output import SwitchCasesInnerOutput
from seaplane.gen.carrier.models.sync_response import SyncResponse



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field
from seaplane.gen.carrier.models.azure_blob_storage_output import AzureBlobStorageOutput
from seaplane.gen.carrier.models.carrier_output import CarrierOutput
from seaplane.gen.carrier.models.http_client_output import HttpClientOutput
from seaplane.gen.carrier.models.sql_raw import SqlRaw
from seaplane.gen.carrier.models.switch import Switch
from seaplane.gen.carrier.models.sync_response import SyncResponse


class Output(BaseModel):
    """
    Flow output
    """

    carrier: Optional[CarrierOutput] = None
    switch: Optional[Switch] = None
    sync_response: Optional[SyncResponse] = None
    drop: Optional[Dict[str, Any]] = Field(
        None, description="Drop a message (but ack input as successful)"
    )
    http_client: Optional[HttpClientOutput] = None
    azure_blob_storage: Optional[AzureBlobStorageOutput] = None
    sql_raw: Optional[SqlRaw] = None
    __properties = [
        "carrier",
        "switch",
        "sync_response",
        "drop",
        "http_client",
        "azure_blob_storage",
        "sql_raw",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Output:
        """Create an instance of Output from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of carrier
        if self.carrier:
            _dict["carrier"] = self.carrier.to_dict()
        # override the default output from pydantic by calling `to_dict()` of switch
        if self.switch:
            _dict["switch"] = self.switch.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sync_response
        if self.sync_response:
            _dict["sync_response"] = self.sync_response.to_dict()
        # override the default output from pydantic by calling `to_dict()` of http_client
        if self.http_client:
            _dict["http_client"] = self.http_client.to_dict()
        # override the default output from pydantic by calling `to_dict()` of azure_blob_storage
        if self.azure_blob_storage:
            _dict["azure_blob_storage"] = self.azure_blob_storage.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sql_raw
        if self.sql_raw:
            _dict["sql_raw"] = self.sql_raw.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Output:
        """Create an instance of Output from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Output.parse_obj(obj)

        _obj = Output.parse_obj(
            {
                "carrier": CarrierOutput.from_dict(obj.get("carrier"))
                if obj.get("carrier") is not None
                else None,
                "switch": Switch.from_dict(obj.get("switch"))
                if obj.get("switch") is not None
                else None,
                "sync_response": SyncResponse.from_dict(obj.get("sync_response"))
                if obj.get("sync_response") is not None
                else None,
                "drop": obj.get("drop"),
                "http_client": HttpClientOutput.from_dict(obj.get("http_client"))
                if obj.get("http_client") is not None
                else None,
                "azure_blob_storage": AzureBlobStorageOutput.from_dict(
                    obj.get("azure_blob_storage")
                )
                if obj.get("azure_blob_storage") is not None
                else None,
                "sql_raw": SqlRaw.from_dict(obj.get("sql_raw"))
                if obj.get("sql_raw") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import (
    BaseModel,
    Field,
    StrictBool,
    StrictInt,
    StrictStr,
    conint,
    conlist,
    constr,
    validator,
)


class CarrierStreamOptions(BaseModel):
    """
    Stream configuration options
    """

    message_ttl: Optional[conint(strict=True, le=86400, ge=0)] = Field(
        0, description="Message TTL in seconds"
    )
    max_messages: Optional[conint(strict=True, le=1000000, ge=0)] = Field(
        1000000, description="Max messages in stream"
    )
    max_size: Optional[conint(strict=True, le=1000000000, ge=0)] = Field(
        100000000, description="Max total size od messages in stream in bytes"
    )
    replicas: Optional[StrictInt] = Field(3, description="Number of replicas (1/3/5)")
    allow_locations: Optional[conlist(constr(strict=True))] = Field(
        None, description="Array of allowed locations"
    )
    deny_locations: Optional[conlist(constr(strict=True))] = Field(
        None, description="Array of denied locations"
    )
    wait_for_ack: Optional[StrictBool] = Field(
        True, description="Should the stream wait for ack"
    )
    ack_timeout: Optional[conint(strict=True, le=60, ge=1)] = Field(
        5, description="How long should the stream wait for ack in seconds"
    )
    max_delivery_attempts: Optional[conint(strict=True, le=1000, ge=1)] = Field(
        5, description="Maximum number of delivery attempts"
    )
    max_delivery_time: Optional[conint(strict=True, le=3600, ge=0)] = Field(
        60, description="Maximum delivery time in seconds"
    )
    dead_letter_sink: Optional[StrictStr] = Field(None, description="TBD")
    allow_direct: Optional[StrictBool] = Field(
        None, description="allow direct message retrieval by subject"
    )
    __properties = [
        "message_ttl",
        "max_messages",
        "max_size",
        "replicas",
        "allow_locations",
        "deny_locations",
        "wait_for_ack",
        "ack_timeout",
        "max_delivery_attempts",
        "max_delivery_time",
        "dead_letter_sink",
        "allow_direct",
    ]

    @validator("replicas")
    def replicas_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (1, 3, 5):
            raise ValueError("must be one of enum values (1, 3, 5)")
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CarrierStreamOptions:
        """Create an instance of CarrierStreamOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CarrierStreamOptions:
        """Create an instance of CarrierStreamOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CarrierStreamOptions.parse_obj(obj)

        _obj = CarrierStreamOptions.parse_obj(
            {
                "message_ttl": obj.get("message_ttl")
                if obj.get("message_ttl") is not None
                else 0,
                "max_messages": obj.get("max_messages")
                if obj.get("max_messages") is not None
                else 1000000,
                "max_size": obj.get("max_size")
                if obj.get("max_size") is not None
                else 100000000,
                "replicas": obj.get("replicas")
                if obj.get("replicas") is not None
                else 3,
                "allow_locations": obj.get("allow_locations"),
                "deny_locations": obj.get("deny_locations"),
                "wait_for_ack": obj.get("wait_for_ack")
                if obj.get("wait_for_ack") is not None
                else True,
                "ack_timeout": obj.get("ack_timeout")
                if obj.get("ack_timeout") is not None
                else 5,
                "max_delivery_attempts": obj.get("max_delivery_attempts")
                if obj.get("max_delivery_attempts") is not None
                else 5,
                "max_delivery_time": obj.get("max_delivery_time")
                if obj.get("max_delivery_time") is not None
                else 60,
                "dead_letter_sink": obj.get("dead_letter_sink"),
                "allow_direct": obj.get("allow_direct"),
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import seaplane.gen.carrier
from seaplane.gen.carrier.models.docker_processor_docker import (
    DockerProcessorDocker,
)  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestDockerProcessorDocker(unittest.TestCase):
    """DockerProcessorDocker unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DockerProcessorDocker
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `DockerProcessorDocker`
        """
        model = seaplane.gen.carrier.models.docker_processor_docker.DockerProcessorDocker()  # noqa: E501
        if include_optional :
            return DockerProcessorDocker(
                image = 'example-image', 
                args = []
            )
        else :
            return DockerProcessorDocker(
                image = 'example-image',
        )
        """

    def testDockerProcessorDocker(self):
        """Test DockerProcessorDocker"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator


class SqlRaw(BaseModel):
    """
    Execute raw sql statement
    """

    driver: StrictStr = Field(..., description="A database driver to use.")
    dsn: StrictStr = Field(
        ...,
        description="DB connection string. `OUTPUT_DSN` Flow secret is the default.",
    )
    query: StrictStr = Field(
        ...,
        description="Query to execute with input, placeholders are database driver specific.",
    )
    args_mapping: Optional[StrictStr] = Field(
        None,
        description="Bloblang mapping which should evaluate to an array of values matching in size to the number of placeholder arguments in the field query.",
    )
    init_statement: Optional[StrictStr] = Field(
        None,
        description="An optional SQL statement to execute immediately upon the first connection to the target database. This is a useful way to initialise tables before processing data. Care should be taken to ensure that the statement is idempotent, and therefore would not cause issues when run multiple times after service restarts.",
    )
    __properties = ["driver", "dsn", "query", "args_mapping", "init_statement"]

    @validator("driver")
    def driver_validate_enum(cls, value):
        """Validates the enum"""
        if value not in (
            "mysql",
            "postgres",
            "clickhouse",
            "mssql",
            "sqlite",
            "oracle",
            "snowflake",
            "trino",
        ):
            raise ValueError(
                "must be one of enum values ('mysql', 'postgres', 'clickhouse', 'mssql', 'sqlite', 'oracle', 'snowflake', 'trino')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SqlRaw:
        """Create an instance of SqlRaw from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SqlRaw:
        """Create an instance of SqlRaw from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SqlRaw.parse_obj(obj)

        _obj = SqlRaw.parse_obj(
            {
                "driver": obj.get("driver"),
                "dsn": obj.get("dsn"),
                "query": obj.get("query"),
                "args_mapping": obj.get("args_mapping"),
                "init_statement": obj.get("init_statement"),
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import seaplane.gen.carrier
from seaplane.gen.carrier.models.sql_raw import SqlRaw  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestSqlRaw(unittest.TestCase):
    """SqlRaw unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SqlRaw
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `SqlRaw`
        """
        model = seaplane.gen.carrier.models.sql_raw.SqlRaw()  # noqa: E501
        if include_optional :
            return SqlRaw(
                driver = 'postgres', 
                dsn = 'postgres://foouser:foopass@localhost:5432/foodb?sslmode=disable', 
                query = 'INSERT INTO footable (foo, bar, baz) VALUES (?, ?, ?);', 
                args_mapping = 'root = [ this.cat.meow, this.doc.woofs[0] ]', 
                init_statement = 'CREATE TABLE IF NOT EXISTS some_table (
  foo varchar(50) not null,
  bar integer,
  baz varchar(50),
  primary key (foo)
) WITHOUT ROWID;
'
            )
        else :
            return SqlRaw(
                driver = 'postgres',
                dsn = 'postgres://foouser:foopass@localhost:5432/foodb?sslmode=disable',
                query = 'INSERT INTO footable (foo, bar, baz) VALUES (?, ?, ?);',
        )
        """

    def testSqlRaw(self):
        """Test SqlRaw"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.object_api import ObjectApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestObjectApi(unittest.TestCase):
    """ObjectApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.object_api.ObjectApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_bucket(self):
        """Test case for create_bucket

        Create a Bucket  # noqa: E501
        """
        pass

    def test_create_object(self):
        """Test case for create_object

        Create an object in a bucket  # noqa: E501
        """
        pass

    def test_delete_bucket(self):
        """Test case for delete_bucket

        Delete a bucket  # noqa: E501
        """
        pass

    def test_delete_object(self):
        """Test case for delete_object

        Delete an object in a bucket  # noqa: E501
        """
        pass

    def test_get_bucket(self):
        """Test case for get_bucket

        Get a bucket summary  # noqa: E501
        """
        pass

    def test_get_object(self):
        """Test case for get_object

        Get an object in a bucket or list under a prefix  # noqa: E501
        """
        pass

    def test_list_buckets(self):
        """Test case for list_buckets

        Get list of all buckets  # noqa: E501
        """
        pass

    def test_list_objects(self):
        """Test case for list_objects

        Get an object in a bucket or list under a prefix  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.endpoint_api import EndpointApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestEndpointApi(unittest.TestCase):
    """EndpointApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.endpoint_api.EndpointApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_archive_from_endpoint(self):
        """Test case for get_archive_from_endpoint

        GET archive from a endpoint  # noqa: E501
        """
        pass

    def test_get_from_endpoint(self):
        """Test case for get_from_endpoint

        GET data from a endpoint  # noqa: E501
        """
        pass

    def test_submit_to_endpoint(self):
        """Test case for submit_to_endpoint

        Create a endpoint request (i.e. ingress)  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401

from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictStr, ValidationError, validator
from seaplane.gen.carrier.models.docker_processor import DockerProcessor
from typing import Any, List
from pydantic import StrictStr, Field

PROCESSOR_ANY_OF_SCHEMAS = ["DockerProcessor", "object"]


class Processor(BaseModel):
    """
    Processor
    """

    # data type: DockerProcessor
    anyof_schema_1_validator: Optional[DockerProcessor] = None
    # data type: object
    anyof_schema_2_validator: Optional[Dict[str, Any]] = Field(
        None, description="Value may be missing"
    )
    actual_instance: Any
    any_of_schemas: List[str] = Field(PROCESSOR_ANY_OF_SCHEMAS, const=True)

    class Config:
        validate_assignment = True

    def __init__(self, *args, **kwargs):
        if args:
            if len(args) > 1:
                raise ValueError(
                    "If a position argument is used, only 1 is allowed to set `actual_instance`"
                )
            if kwargs:
                raise ValueError(
                    "If a position argument is used, keyword arguments cannot be used."
                )
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @validator("actual_instance")
    def actual_instance_must_validate_anyof(cls, v):
        if v is None:
            return v

        instance = Processor.construct()
        error_messages = []
        # validate data type: DockerProcessor
        if not isinstance(v, DockerProcessor):
            error_messages.append(
                f"Error! Input type `{type(v)}` is not `DockerProcessor`"
            )
        else:
            return v

        # validate data type: object
        try:
            instance.anyof_schema_2_validator = v
            return v
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        if error_messages:
            # no match
            raise ValueError(
                "No match found when setting the actual_instance in Processor with anyOf schemas: DockerProcessor, object. Details: "
                + ", ".join(error_messages)
            )
        else:
            return v

    @classmethod
    def from_dict(cls, obj: dict) -> Processor:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Processor:
        """Returns the object represented by the json string"""
        instance = Processor.construct()
        if json_str is None:
            return instance

        error_messages = []
        # anyof_schema_1_validator: Optional[DockerProcessor] = None
        try:
            instance.actual_instance = DockerProcessor.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into object
        try:
            # validation
            instance.anyof_schema_2_validator = json.loads(json_str)
            # assign value to actual_instance
            instance.actual_instance = instance.anyof_schema_2_validator
            return instance
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if error_messages:
            # no match
            raise ValueError(
                "No match found when deserializing the JSON string into Processor with anyOf schemas: DockerProcessor, object. Details: "
                + ", ".join(error_messages)
            )
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        to_json = getattr(self.actual_instance, "to_json", None)
        if callable(to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> dict:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        to_json = getattr(self.actual_instance, "to_json", None)
        if callable(to_json):
            return self.actual_instance.to_dict()
        else:
            return json.dumps(self.actual_instance)

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.dict())



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.event_api import EventApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestEventApi(unittest.TestCase):
    """EventApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.event_api.EventApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_stream_events(self):
        """Test case for stream_events

        Stream events with SSE  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.flow_api import FlowApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestFlowApi(unittest.TestCase):
    """FlowApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.flow_api.FlowApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_flow(self):
        """Test case for create_flow

        Create a Flow  # noqa: E501
        """
        pass

    def test_delete_flow(self):
        """Test case for delete_flow

        Delete a Flow  # noqa: E501
        """
        pass

    def test_delete_secret(self):
        """Test case for delete_secret

        Delete a single secret k/v.  # noqa: E501
        """
        pass

    def test_get_flow(self):
        """Test case for get_flow

        Get a Flow summary  # noqa: E501
        """
        pass

    def test_get_flow_status(self):
        """Test case for get_flow_status

        Get the status of a flow's composite allocations  # noqa: E501
        """
        pass

    def test_get_secret(self):
        """Test case for get_secret

        Get secret details  # noqa: E501
        """
        pass

    def test_list_flows(self):
        """Test case for list_flows

        Get list of all flows  # noqa: E501
        """
        pass

    def test_list_secrets(self):
        """Test case for list_secrets

        List all secrets  # noqa: E501
        """
        pass

    def test_set_secret(self):
        """Test case for set_secret

        Set the secret value  # noqa: E501
        """
        pass

    def test_set_secrets(self):
        """Test case for set_secrets

        Set all secrets  # noqa: E501
        """
        pass

    def test_stream_flow_events(self):
        """Test case for stream_flow_events

        Stream flow events with SSE  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conint, conlist, constr, validator


class KeyValueConfig(BaseModel):
    """
    The set of possible values to configure on a specific key-value store.
    """

    max_value_size: Optional[StrictInt] = Field(
        2097152, description="The maximum size of a value, in bytes"
    )
    history: Optional[conint(strict=True, le=64, ge=1)] = Field(
        16, description="The number of versions to keep in history for each key"
    )
    ttl: Optional[conint(strict=True, le=315360000, ge=0)] = Field(
        None, description="Optionally sets a key to expire after this many seconds."
    )
    replicas: Optional[StrictInt] = Field(3, description="Number of replicas (1/3/5)")
    allow_locations: Optional[conlist(constr(strict=True))] = Field(
        None, description="Array of allowed locations"
    )
    deny_locations: Optional[conlist(constr(strict=True))] = Field(
        None, description="Array of denied locations"
    )
    __properties = [
        "max_value_size",
        "history",
        "ttl",
        "replicas",
        "allow_locations",
        "deny_locations",
    ]

    @validator("replicas")
    def replicas_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (1, 3, 5):
            raise ValueError("must be one of enum values (1, 3, 5)")
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> KeyValueConfig:
        """Create an instance of KeyValueConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> KeyValueConfig:
        """Create an instance of KeyValueConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return KeyValueConfig.parse_obj(obj)

        _obj = KeyValueConfig.parse_obj(
            {
                "max_value_size": obj.get("max_value_size")
                if obj.get("max_value_size") is not None
                else 2097152,
                "history": obj.get("history") if obj.get("history") is not None else 16,
                "ttl": obj.get("ttl"),
                "replicas": obj.get("replicas")
                if obj.get("replicas") is not None
                else 3,
                "allow_locations": obj.get("allow_locations"),
                "deny_locations": obj.get("deny_locations"),
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from seaplane.gen.carrier.models.carrier_stream_details import CarrierStreamDetails
from seaplane.gen.carrier.models.carrier_stream_options import CarrierStreamOptions


class CarrierStream(BaseModel):
    """
    Information about the stream
    """

    name: Optional[StrictStr] = Field(None, description="Stream name")
    options: Optional[CarrierStreamOptions] = None
    details: Optional[CarrierStreamDetails] = None
    __properties = ["name", "options", "details"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CarrierStream:
        """Create an instance of CarrierStream from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of options
        if self.options:
            _dict["options"] = self.options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of details
        if self.details:
            _dict["details"] = self.details.to_dict()
        # set to None if options (nullable) is None
        # and __fields_set__ contains the field
        if self.options is None and "options" in self.__fields_set__:
            _dict["options"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CarrierStream:
        """Create an instance of CarrierStream from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CarrierStream.parse_obj(obj)

        _obj = CarrierStream.parse_obj(
            {
                "name": obj.get("name"),
                "options": CarrierStreamOptions.from_dict(obj.get("options"))
                if obj.get("options") is not None
                else None,
                "details": CarrierStreamDetails.from_dict(obj.get("details"))
                if obj.get("details") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conint, constr, validator


class CarrierInputConfig(BaseModel):
    """
    Configuration for Carrier stream input
    """

    stream: Optional[constr(strict=True, max_length=64, min_length=1)] = Field(
        None, description="stream (mutually exclusive with subject)"
    )
    subject: Optional[constr(strict=True)] = Field(
        None,
        description="Space-delimited list of subjects to subscribe to (mutually exclusive with stream). Note that multiple subjects are only allowed when attached to existing pull consumers. ",
    )
    queue: Optional[StrictStr] = Field(None, description="Queue group (optional)")
    durable: Optional[constr(strict=True)] = Field(
        None, description="Durable consumer name (optional)"
    )
    bind: Optional[StrictBool] = Field(None, description="Bind to an existing consumer")
    deliver: Optional[StrictStr] = Field(
        "all",
        description="Start consuming with a durable consumer. This cannot be updated once a consumer is created",
    )
    ack_wait: Optional[constr(strict=True)] = Field(
        "30s",
        description="The maximum amount of time NATS server should wait for an ack from consumer",
    )
    max_ack_pending: Optional[conint(strict=True, le=100000, ge=1)] = Field(
        1024, description="Allowed in-flight messages before halting"
    )
    __properties = [
        "stream",
        "subject",
        "queue",
        "durable",
        "bind",
        "deliver",
        "ack_wait",
        "max_ack_pending",
    ]

    @validator("stream")
    def stream_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[a-zA-Z0-9-_]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-zA-Z0-9-_]+$/")
        return value

    @validator("subject")
    def subject_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(
            r"^([a-zA-Z0-9-_]{1,64}(.[a-zA-Z0-9-_*]{1,64})*(.>)?)([ ]([a-zA-Z0-9-_]{1,64}(.[a-zA-Z0-9-_*]{1,64})*(.>)?))*$",
            value,
        ):
            raise ValueError(
                r"must validate the regular expression /^([a-zA-Z0-9-_]{1,64}(.[a-zA-Z0-9-_*]{1,64})*(.>)?)([ ]([a-zA-Z0-9-_]{1,64}(.[a-zA-Z0-9-_*]{1,64})*(.>)?))*$/"
            )
        return value

    @validator("durable")
    def durable_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[a-zA-Z0-9-_]{1,32}$", value):
            raise ValueError(
                r"must validate the regular expression /^[a-zA-Z0-9-_]{1,32}$/"
            )
        return value

    @validator("deliver")
    def deliver_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("all", "last", "new"):
            raise ValueError("must be one of enum values ('all', 'last', 'new')")
        return value

    @validator("ack_wait")
    def ack_wait_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^([0-9]{1,6}h|[0-9]{1,7}m|[0-9]{1,9}s)$", value):
            raise ValueError(
                r"must validate the regular expression /^([0-9]{1,6}h|[0-9]{1,7}m|[0-9]{1,9}s)$/"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CarrierInputConfig:
        """Create an instance of CarrierInputConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CarrierInputConfig:
        """Create an instance of CarrierInputConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CarrierInputConfig.parse_obj(obj)

        _obj = CarrierInputConfig.parse_obj(
            {
                "stream": obj.get("stream"),
                "subject": obj.get("subject"),
                "queue": obj.get("queue"),
                "durable": obj.get("durable"),
                "bind": obj.get("bind"),
                "deliver": obj.get("deliver")
                if obj.get("deliver") is not None
                else "all",
                "ack_wait": obj.get("ack_wait")
                if obj.get("ack_wait") is not None
                else "30s",
                "max_ack_pending": obj.get("max_ack_pending")
                if obj.get("max_ack_pending") is not None
                else 1024,
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


__version__ = "0.0.16.beta1"

# import apis into sdk package
from seaplane.gen.carrier.api.endpoint_api import EndpointApi
from seaplane.gen.carrier.api.event_api import EventApi
from seaplane.gen.carrier.api.flow_api import FlowApi
from seaplane.gen.carrier.api.key_value_api import KeyValueApi
from seaplane.gen.carrier.api.object_api import ObjectApi
from seaplane.gen.carrier.api.stream_api import StreamApi
from seaplane.gen.carrier.api.webhook_api import WebhookApi

# import ApiClient
from seaplane.gen.carrier.api_response import ApiResponse
from seaplane.gen.carrier.api_client import ApiClient
from seaplane.gen.carrier.configuration import Configuration
from seaplane.gen.carrier.exceptions import OpenApiException
from seaplane.gen.carrier.exceptions import ApiTypeError
from seaplane.gen.carrier.exceptions import ApiValueError
from seaplane.gen.carrier.exceptions import ApiKeyError
from seaplane.gen.carrier.exceptions import ApiAttributeError
from seaplane.gen.carrier.exceptions import ApiException

# import models into sdk package
from seaplane.gen.carrier.models.azure_blob_storage_output import AzureBlobStorageOutput
from seaplane.gen.carrier.models.broker_item import BrokerItem
from seaplane.gen.carrier.models.bucket import Bucket
from seaplane.gen.carrier.models.carrier_input_config import CarrierInputConfig
from seaplane.gen.carrier.models.carrier_output import CarrierOutput
from seaplane.gen.carrier.models.carrier_stream import CarrierStream
from seaplane.gen.carrier.models.carrier_stream_details import CarrierStreamDetails
from seaplane.gen.carrier.models.carrier_stream_options import CarrierStreamOptions
from seaplane.gen.carrier.models.cors import Cors
from seaplane.gen.carrier.models.docker_processor import DockerProcessor
from seaplane.gen.carrier.models.docker_processor_docker import DockerProcessorDocker
from seaplane.gen.carrier.models.docker_processor_resources import (
    DockerProcessorResources,
)
from seaplane.gen.carrier.models.docker_processor_resources_limits import (
    DockerProcessorResourcesLimits,
)
from seaplane.gen.carrier.models.docker_processor_resources_requests import (
    DockerProcessorResourcesRequests,
)
from seaplane.gen.carrier.models.error import Error
from seaplane.gen.carrier.models.flow import Flow
from seaplane.gen.carrier.models.get_store200_response import GetStore200Response
from seaplane.gen.carrier.models.http_server_config import HTTPServerConfig
from seaplane.gen.carrier.models.http_client_output import HttpClientOutput
from seaplane.gen.carrier.models.input import Input
from seaplane.gen.carrier.models.key_value_config import KeyValueConfig
from seaplane.gen.carrier.models.metadata_headers import MetadataHeaders
from seaplane.gen.carrier.models.object_stat import ObjectStat
from seaplane.gen.carrier.models.output import Output
from seaplane.gen.carrier.models.processor import Processor
from seaplane.gen.carrier.models.secret import Secret
from seaplane.gen.carrier.models.sql_raw import SqlRaw
from seaplane.gen.carrier.models.submit_to_endpoint201_response import (
    SubmitToEndpoint201Response,
)
from seaplane.gen.carrier.models.switch import Switch
from seaplane.gen.carrier.models.switch_cases_inner import SwitchCasesInner
from seaplane.gen.carrier.models.switch_cases_inner_output import SwitchCasesInnerOutput
from seaplane.gen.carrier.models.sync_response import SyncResponse



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist, constr, validator
from seaplane.gen.carrier.models.cors import Cors


class HTTPServerConfig(BaseModel):
    """
    HTTP server configuration
    """

    address: Optional[StrictStr] = Field(
        None,
        description="An alternative address to host from. If left empty the service wide address is used.",
    )
    path: Optional[constr(strict=True)] = Field(
        "/", description="The endpoint path to listen for POST requests."
    )
    ws_path: Optional[StrictStr] = Field(
        None, description="The endpoint path to create websocket connections from."
    )
    ws_welcome_message: Optional[StrictStr] = Field(
        None,
        description="An optional message to deliver to fresh websocket connections.",
    )
    ws_rate_limit_message: Optional[StrictStr] = Field(
        None,
        description="An optional message to delivery to websocket connections that are rate limited.",
    )
    allowed_verbs: Optional[conlist(StrictStr)] = Field(
        None, description="An array of verbs that are allowed for the path endpoint."
    )
    timeout: Optional[StrictStr] = Field(
        None,
        description="Timeout for requests. If a consumed messages takes longer than this to be delivered the connection is closed, but the message may still be delivered.",
    )
    rate_limit: Optional[StrictStr] = Field(
        None, description="An optional rate limit to throttle requests by."
    )
    cert_file: Optional[StrictStr] = Field(
        None,
        description="Enable TLS by specifying a certificate and key file. Only valid with a custom address.",
    )
    key_file: Optional[StrictStr] = Field(
        None,
        description="Enable TLS by specifying a certificate and key file. Only valid with a custom address.",
    )
    cors: Optional[Cors] = None
    __properties = [
        "address",
        "path",
        "ws_path",
        "ws_welcome_message",
        "ws_rate_limit_message",
        "allowed_verbs",
        "timeout",
        "rate_limit",
        "cert_file",
        "key_file",
        "cors",
    ]

    @validator("path")
    def path_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"[\/].*", value):
            raise ValueError(r"must validate the regular expression /[\/].*/")
        return value

    @validator("allowed_verbs")
    def allowed_verbs_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in ("GET", "POST", "PUT", "DELETE"):
                raise ValueError(
                    "each list item must be one of ('GET', 'POST', 'PUT', 'DELETE')"
                )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> HTTPServerConfig:
        """Create an instance of HTTPServerConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of cors
        if self.cors:
            _dict["cors"] = self.cors.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> HTTPServerConfig:
        """Create an instance of HTTPServerConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return HTTPServerConfig.parse_obj(obj)

        _obj = HTTPServerConfig.parse_obj(
            {
                "address": obj.get("address"),
                "path": obj.get("path") if obj.get("path") is not None else "/",
                "ws_path": obj.get("ws_path"),
                "ws_welcome_message": obj.get("ws_welcome_message"),
                "ws_rate_limit_message": obj.get("ws_rate_limit_message"),
                "allowed_verbs": obj.get("allowed_verbs"),
                "timeout": obj.get("timeout"),
                "rate_limit": obj.get("rate_limit"),
                "cert_file": obj.get("cert_file"),
                "key_file": obj.get("key_file"),
                "cors": Cors.from_dict(obj.get("cors"))
                if obj.get("cors") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, constr, validator


class AzureBlobStorageOutput(BaseModel):
    """
    defines model for AzureBlobStorageOutput
    """

    storage_account: Optional[StrictStr] = Field(
        "",
        description="The storage account to access. This field is ignored if storage_connection_string is set.",
    )
    storage_access_key: Optional[StrictStr] = Field(
        "",
        description="The storage account access key. This field is ignored if storage_connection_string is set.",
    )
    storage_sas_token: Optional[StrictStr] = Field(
        "",
        description="The storage account SAS token. This field is ignored if storage_connection_string or storage_access_key are set.",
    )
    storage_connection_string: Optional[StrictStr] = Field(
        "",
        description="A storage account connection string. This field is required if storage_account and storage_access_key / storage_sas_token are not set.",
    )
    container: constr(strict=True) = Field(
        ...,
        description="The container for uploading the messages to. This field supports interpolation functions.",
    )
    path: Optional[StrictStr] = Field(
        '${!count("files")}-${!timestamp_unix_nano()}.txt',
        description="The path of each message to upload. This field supports interpolation functions.",
    )
    blob_type: Optional[StrictStr] = Field(
        "BLOCK",
        description='Block and Append blobs are comprised of blocks, and each blob can support up to 50,000 blocks. The default value is +"BLOCK"+.` This field supports interpolation function',
    )
    public_access_level: Optional[StrictStr] = Field(
        "PRIVATE",
        description="The container's public access level. The default value is PRIVATE. This field supports interpolation functions.",
    )
    max_in_flight: Optional[StrictInt] = Field(
        64,
        description="The maximum number of messages to have in flight at a given time. Increase this to improve throughput.",
    )
    __properties = [
        "storage_account",
        "storage_access_key",
        "storage_sas_token",
        "storage_connection_string",
        "container",
        "path",
        "blob_type",
        "public_access_level",
        "max_in_flight",
    ]

    @validator("container")
    def container_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^.+$", value):
            raise ValueError(r"must validate the regular expression /^.+$/")
        return value

    @validator("blob_type")
    def blob_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("BLOCK", "APPEND"):
            raise ValueError("must be one of enum values ('BLOCK', 'APPEND')")
        return value

    @validator("public_access_level")
    def public_access_level_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("PRIVATE", "BLOB", "CONTAINER"):
            raise ValueError(
                "must be one of enum values ('PRIVATE', 'BLOB', 'CONTAINER')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AzureBlobStorageOutput:
        """Create an instance of AzureBlobStorageOutput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AzureBlobStorageOutput:
        """Create an instance of AzureBlobStorageOutput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AzureBlobStorageOutput.parse_obj(obj)

        _obj = AzureBlobStorageOutput.parse_obj(
            {
                "storage_account": obj.get("storage_account")
                if obj.get("storage_account") is not None
                else "",
                "storage_access_key": obj.get("storage_access_key")
                if obj.get("storage_access_key") is not None
                else "",
                "storage_sas_token": obj.get("storage_sas_token")
                if obj.get("storage_sas_token") is not None
                else "",
                "storage_connection_string": obj.get("storage_connection_string")
                if obj.get("storage_connection_string") is not None
                else "",
                "container": obj.get("container"),
                "path": obj.get("path")
                if obj.get("path") is not None
                else '${!count("files")}-${!timestamp_unix_nano()}.txt',
                "blob_type": obj.get("blob_type")
                if obj.get("blob_type") is not None
                else "BLOCK",
                "public_access_level": obj.get("public_access_level")
                if obj.get("public_access_level") is not None
                else "PRIVATE",
                "max_in_flight": obj.get("max_in_flight")
                if obj.get("max_in_flight") is not None
                else 64,
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist


class Cors(BaseModel):
    """
    Adds Cross-Origin Resource Sharing headers. Only valid with a custom address.
    """

    enabled: StrictBool = Field(..., description="Allow cross-origin requests")
    allowed_origins: conlist(StrictStr) = Field(
        ..., description="List of allowed origins"
    )
    __properties = ["enabled", "allowed_origins"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Cors:
        """Create an instance of Cors from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Cors:
        """Create an instance of Cors from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Cors.parse_obj(obj)

        _obj = Cors.parse_obj(
            {
                "enabled": obj.get("enabled"),
                "allowed_origins": obj.get("allowed_origins"),
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from typing_extensions import Annotated
from pydantic import Field, StrictBytes, StrictStr, constr, validator

from typing import List, Optional, Union

from seaplane.gen.carrier.models.get_store200_response import GetStore200Response
from seaplane.gen.carrier.models.key_value_config import KeyValueConfig

from seaplane.gen.carrier.api_client import ApiClient
from seaplane.gen.carrier.api_response import ApiResponse
from seaplane.gen.carrier.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class KeyValueApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_store(
        self,
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        key_value_config: Optional[KeyValueConfig] = None,
        **kwargs
    ) -> None:  # noqa: E501
        """Create a new key-value store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_store(kv_store, key_value_config, async_req=True)
        >>> result = thread.get()

        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param key_value_config:
        :type key_value_config: KeyValueConfig
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the create_store_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.create_store_with_http_info(
            kv_store, key_value_config, **kwargs
        )  # noqa: E501

    @validate_arguments
    def create_store_with_http_info(
        self,
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        key_value_config: Optional[KeyValueConfig] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Create a new key-value store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_store_with_http_info(kv_store, key_value_config, async_req=True)
        >>> result = thread.get()

        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param key_value_config:
        :type key_value_config: KeyValueConfig
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = ["kv_store", "key_value_config"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_store" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["kv_store"]:
            _path_params["kv_store"] = _params["kv_store"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["key_value_config"] is not None:
            _body_params = _params["key_value_config"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            "/kv/{kv_store}",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def delete_key(
        self,
        key: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key in the key-value store."),
        ],
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        if_match: Annotated[
            Optional[constr(strict=True, max_length=128, min_length=1)],
            Field(
                description="The ETag value to delete. If omitted will delete any value encountered at that key name."
            ),
        ] = None,
        purge: Annotated[
            Optional[StrictStr],
            Field(
                description='Whether or not to delete all history related to a key. A "false" value (default) means that previous versions will be retained & visible if the key is recreated.'
            ),
        ] = None,
        **kwargs
    ) -> None:  # noqa: E501
        """Remove an entry from the key-value store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_key(key, kv_store, if_match, purge, async_req=True)
        >>> result = thread.get()

        :param key: Name of a key in the key-value store. (required)
        :type key: str
        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param if_match: The ETag value to delete. If omitted will delete any value encountered at that key name.
        :type if_match: str
        :param purge: Whether or not to delete all history related to a key. A \"false\" value (default) means that previous versions will be retained & visible if the key is recreated.
        :type purge: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the delete_key_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.delete_key_with_http_info(
            key, kv_store, if_match, purge, **kwargs
        )  # noqa: E501

    @validate_arguments
    def delete_key_with_http_info(
        self,
        key: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key in the key-value store."),
        ],
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        if_match: Annotated[
            Optional[constr(strict=True, max_length=128, min_length=1)],
            Field(
                description="The ETag value to delete. If omitted will delete any value encountered at that key name."
            ),
        ] = None,
        purge: Annotated[
            Optional[StrictStr],
            Field(
                description='Whether or not to delete all history related to a key. A "false" value (default) means that previous versions will be retained & visible if the key is recreated.'
            ),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Remove an entry from the key-value store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_key_with_http_info(key, kv_store, if_match, purge, async_req=True)
        >>> result = thread.get()

        :param key: Name of a key in the key-value store. (required)
        :type key: str
        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param if_match: The ETag value to delete. If omitted will delete any value encountered at that key name.
        :type if_match: str
        :param purge: Whether or not to delete all history related to a key. A \"false\" value (default) means that previous versions will be retained & visible if the key is recreated.
        :type purge: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = ["key", "kv_store", "if_match", "purge"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_key" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["key"]:
            _path_params["key"] = _params["key"]

        if _params["kv_store"]:
            _path_params["kv_store"] = _params["kv_store"]

        # process the query parameters
        _query_params = []
        if _params.get("purge") is not None:  # noqa: E501
            _query_params.append(("purge", _params["purge"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        if _params["if_match"]:
            _header_params["If-Match"] = _params["if_match"]

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            "/kv/{kv_store}/key/{key}",
            "DELETE",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def delete_store(
        self,
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        **kwargs
    ) -> None:  # noqa: E501
        """Deletes an existing key-value store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_store(kv_store, async_req=True)
        >>> result = thread.get()

        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the delete_store_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.delete_store_with_http_info(kv_store, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_store_with_http_info(
        self,
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Deletes an existing key-value store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_store_with_http_info(kv_store, async_req=True)
        >>> result = thread.get()

        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = ["kv_store"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_store" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["kv_store"]:
            _path_params["kv_store"] = _params["kv_store"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            "/kv/{kv_store}",
            "DELETE",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_key(
        self,
        key: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key in the key-value store."),
        ],
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        if_match: Annotated[
            Optional[constr(strict=True, max_length=128, min_length=1)],
            Field(
                description="The Etag version of the value to get. If omitted will retrieve the latest version."
            ),
        ] = None,
        **kwargs
    ) -> bytearray:  # noqa: E501
        """Get a Key-Value entry  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_key(key, kv_store, if_match, async_req=True)
        >>> result = thread.get()

        :param key: Name of a key in the key-value store. (required)
        :type key: str
        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param if_match: The Etag version of the value to get. If omitted will retrieve the latest version.
        :type if_match: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: bytearray
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the get_key_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.get_key_with_http_info(
            key, kv_store, if_match, **kwargs
        )  # noqa: E501

    @validate_arguments
    def get_key_with_http_info(
        self,
        key: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key in the key-value store."),
        ],
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        if_match: Annotated[
            Optional[constr(strict=True, max_length=128, min_length=1)],
            Field(
                description="The Etag version of the value to get. If omitted will retrieve the latest version."
            ),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Get a Key-Value entry  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_key_with_http_info(key, kv_store, if_match, async_req=True)
        >>> result = thread.get()

        :param key: Name of a key in the key-value store. (required)
        :type key: str
        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param if_match: The Etag version of the value to get. If omitted will retrieve the latest version.
        :type if_match: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(bytearray, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["key", "kv_store", "if_match"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_key" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["key"]:
            _path_params["key"] = _params["key"]

        if _params["kv_store"]:
            _path_params["kv_store"] = _params["kv_store"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        if _params["if_match"]:
            _header_params["If-Match"] = _params["if_match"]

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/octet-stream", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "bytearray",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/kv/{kv_store}/key/{key}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_store(
        self,
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        **kwargs
    ) -> GetStore200Response:  # noqa: E501
        """Get information about a Key-Value store  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_store(kv_store, async_req=True)
        >>> result = thread.get()

        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetStore200Response
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the get_store_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.get_store_with_http_info(kv_store, **kwargs)  # noqa: E501

    @validate_arguments
    def get_store_with_http_info(
        self,
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Get information about a Key-Value store  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_store_with_http_info(kv_store, async_req=True)
        >>> result = thread.get()

        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetStore200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["kv_store"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_store" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["kv_store"]:
            _path_params["kv_store"] = _params["kv_store"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "GetStore200Response",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/kv/{kv_store}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_keys(
        self,
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        **kwargs
    ) -> List[str]:  # noqa: E501
        """Get the list of keys currently in a store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_keys(kv_store, async_req=True)
        >>> result = thread.get()

        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[str]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the list_keys_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.list_keys_with_http_info(kv_store, **kwargs)  # noqa: E501

    @validate_arguments
    def list_keys_with_http_info(
        self,
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Get the list of keys currently in a store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_keys_with_http_info(kv_store, async_req=True)
        >>> result = thread.get()

        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[str], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["kv_store"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_keys" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["kv_store"]:
            _path_params["kv_store"] = _params["kv_store"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "List[str]",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/kv/{kv_store}/key",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_stores(self, **kwargs) -> List[str]:  # noqa: E501
        """Get information about all Key-Value stores  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_stores(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[str]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the list_stores_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.list_stores_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def list_stores_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """Get information about all Key-Value stores  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_stores_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[str], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = []
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_stores" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "List[str]",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/kv",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def put_key(
        self,
        key: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key in the key-value store."),
        ],
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        if_match: Annotated[
            Optional[constr(strict=True, max_length=128, min_length=1)],
            Field(
                description="The previous ETag value to replace. If omitted will unconditionally overwrite any existing value at that key."
            ),
        ] = None,
        if_not_match: Annotated[
            Optional[constr(strict=True)],
            Field(
                description="If set, then this will only create the key if it does not already exist."
            ),
        ] = None,
        body: Optional[Union[StrictBytes, StrictStr]] = None,
        **kwargs
    ) -> None:  # noqa: E501
        """Place an entry into the key-value store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_key(key, kv_store, if_match, if_not_match, body, async_req=True)
        >>> result = thread.get()

        :param key: Name of a key in the key-value store. (required)
        :type key: str
        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param if_match: The previous ETag value to replace. If omitted will unconditionally overwrite any existing value at that key.
        :type if_match: str
        :param if_not_match: If set, then this will only create the key if it does not already exist.
        :type if_not_match: str
        :param body:
        :type body: bytearray
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the put_key_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.put_key_with_http_info(
            key, kv_store, if_match, if_not_match, body, **kwargs
        )  # noqa: E501

    @validate_arguments
    def put_key_with_http_info(
        self,
        key: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key in the key-value store."),
        ],
        kv_store: Annotated[
            constr(strict=True),
            Field(..., description="Name of a key-value store to operate on."),
        ],
        if_match: Annotated[
            Optional[constr(strict=True, max_length=128, min_length=1)],
            Field(
                description="The previous ETag value to replace. If omitted will unconditionally overwrite any existing value at that key."
            ),
        ] = None,
        if_not_match: Annotated[
            Optional[constr(strict=True)],
            Field(
                description="If set, then this will only create the key if it does not already exist."
            ),
        ] = None,
        body: Optional[Union[StrictBytes, StrictStr]] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Place an entry into the key-value store.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_key_with_http_info(key, kv_store, if_match, if_not_match, body, async_req=True)
        >>> result = thread.get()

        :param key: Name of a key in the key-value store. (required)
        :type key: str
        :param kv_store: Name of a key-value store to operate on. (required)
        :type kv_store: str
        :param if_match: The previous ETag value to replace. If omitted will unconditionally overwrite any existing value at that key.
        :type if_match: str
        :param if_not_match: If set, then this will only create the key if it does not already exist.
        :type if_not_match: str
        :param body:
        :type body: bytearray
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = ["key", "kv_store", "if_match", "if_not_match", "body"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_key" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["key"]:
            _path_params["key"] = _params["key"]

        if _params["kv_store"]:
            _path_params["kv_store"] = _params["kv_store"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        if _params["if_match"]:
            _header_params["If-Match"] = _params["if_match"]

        if _params["if_not_match"]:
            _header_params["If-Not-Match"] = _params["if_not_match"]

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["body"] is not None:
            _body_params = _params["body"]
            # convert to byte array if the input is a file name (str)
            if isinstance(_body_params, str):
                with io.open(_body_params, "rb") as _fp:
                    _body_params_from_file = _fp.read()
                _body_params = _body_params_from_file

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/octet-stream"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            "/kv/{kv_store}/key/{key}",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.0.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictStr, constr, validator


class HttpClientOutputHttpClient(BaseModel):
    """
    HTTP Client output configuration
    """

    url: constr(strict=True) = Field(..., description="The URL to connect to")
    method: Optional[StrictStr] = Field(
        "POST", description="The HTTP method to use for the request."
    )
    headers: Optional[Dict[str, StrictStr]] = Field(
        None, description="A set of extra header values to set on the request"
    )
    __properties = ["url", "method", "headers"]

    @validator("url")
    def url_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"[^ ]+", value):
            raise ValueError(r"must validate the regular expression /[^ ]+/")
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> HttpClientOutputHttpClient:
        """Create an instance of HttpClientOutputHttpClient from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> HttpClientOutputHttpClient:
        """Create an instance of HttpClientOutputHttpClient from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return HttpClientOutputHttpClient.parse_obj(obj)

        _obj = HttpClientOutputHttpClient.parse_obj(
            {
                "url": obj.get("url"),
                "method": obj.get("method")
                if obj.get("method") is not None
                else "POST",
                "headers": obj.get("headers"),
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import seaplane.gen.carrier
from seaplane.gen.carrier.models.carrier_stream_options import (
    CarrierStreamOptions,
)  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestCarrierStreamOptions(unittest.TestCase):
    """CarrierStreamOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CarrierStreamOptions
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CarrierStreamOptions`
        """
        model = seaplane.gen.carrier.models.carrier_stream_options.CarrierStreamOptions()  # noqa: E501
        if include_optional :
            return CarrierStreamOptions(
                message_ttl = 3600, 
                max_messages = 1000000, 
                max_size = 100000000, 
                replicas = 3, 
                allow_locations = ["region/xn"], 
                deny_locations = ["country/nl"], 
                wait_for_ack = True, 
                ack_timeout = 5, 
                max_delivery_attempts = 5, 
                max_delivery_time = 60, 
                dead_letter_sink = 'dead-letter-sink', 
                allow_direct = False
            )
        else :
            return CarrierStreamOptions(
        )
        """

    def testCarrierStreamOptions(self):
        """Test CarrierStreamOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# flake8: noqa

# import apis into api package
from seaplane.gen.carrier.api.endpoint_api import EndpointApi
from seaplane.gen.carrier.api.event_api import EventApi
from seaplane.gen.carrier.api.flow_api import FlowApi
from seaplane.gen.carrier.api.key_value_api import KeyValueApi
from seaplane.gen.carrier.api.object_api import ObjectApi
from seaplane.gen.carrier.api.stream_api import StreamApi
from seaplane.gen.carrier.api.webhook_api import WebhookApi



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from setuptools import setup, find_namespace_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "seaplane.api"
VERSION = "0.0.16.beta1"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = ["urllib3 >= 1.25.3", "python-dateutil", "pydantic >= 1.10.5, < 2", "aenum"]

setup(
    name=NAME,
    version=VERSION,
    description="Carrier API",
    author="Seaplane IO, Inc.",
    author_email="support@seaplane.io",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Carrier API"],
    install_requires=REQUIRES,
    packages=find_namespace_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache 2.0",
    long_description_content_type="text/markdown",
    long_description="""\
    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501
    """,
)
